# PeachCloud :peach: :cloud:

PeachCloud is an open-source platform for deploying and maintaining peer-to-peer communication networks. With Secure Scuttlebutt (SSB) at its core, it has been designed to lower the barrier to entry for users to collectively own and operate their own decentralised infrastructure. The system has been designed to run reliably on single-board computers, making it an ideal low-emissions platform for rural areas, disaster zones and off-grid communities.

[**We welcome your support on our OpenCollective!**](https://opencollective.com/peachcloud)

## :book: [Read our documentation](http://docs.peachcloud.org)

## Background

The project was started by Mikey (@dinosaur) in 2018. See these cypherlinks for details:

- April 2018 project proposal: [`%HqwAsltORROCh4uyOq6iV+SsqU3OuNUevnq+5dwCqVI=.sha256`](https://viewer.scuttlebot.io/%25HqwAsltORROCh4uyOq6iV%2BSsqU3OuNUevnq%2B5dwCqVI%3D.sha256)
- November 2018 project pivot: [`%9NCyTf+oBxG0APlXRCKtrGZj3t+i+Kp3pKPN1gtFX2c=.sha256`](https://viewer.scuttlebot.io/%259NCyTf%2BoBxG0APlXRCKtrGZj3t%2Bi%2BKp3pKPN1gtFX2c%3D.sha256)

## Active Repositories

**Documentation**

 - [peach-devdocs](https://git.coopcloud.tech/PeachCloud/peach-devdocs) - Developer documentation for PeachCloud in the form of a Markdown book ([view online](http://docs.peachcloud.org/))

**Dynamic DNS**

 - [peach-dynsdns-server](https://git.coopcloud.tech/PeachCloud/peach-dyndns-server) - A dynamic DNS server to host the names of guests with changing IP addresses by providing an HTTP API for updating bind9 configurations
 - [peach-dyndns-updater](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-dyndns-updater) - Use a systemd timer and nsudpate to keep the IP address of a dynamic DNS record up to date

**Devops**

 - [peach-vps](https://github.com/peachcloud/peach-vps) - Setup scripts and configuration files for deploying a PeachCloud development server
 
**Image building & device configuration**

 - [peach-config](https://github.com/peachcloud/peach-config) - Configuration instructions, files and scripts
 - [peach-img-builder](https://github.com/peachcloud/peach-img-builder) - Vmdb2 script for building a Debian disc image for Raspberry Pi with PeachCloud pre-installed

**Microservices**

 - [peach-buttons](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-buttons) - Emit GPIO events using JSON-RPC pubsub over WS
 - [peach-oled](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-oled) - Write and draw to OLED display using JSON-RPC over HTTP
 - [peach-menu](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-menu) - A menu for monitoring and interacting with the PeachCloud device
 - [peach-network](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-network) - Query and configure network interfaces using JSON-RPC over HTTP
 - [peach-stats](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-stats) - Query system statistics using JSON-RPC over HTTP
 - [peach-lib](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-lib) - JSON-RPC client library for the PeachCloud ecosystem

**Diagnostics**

 - [peach-probe](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-probe) - Probe PeachCloud microservices to evaluate their state and ensure correct API responses

**Web interface**

 - [peach-patterns](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-patterns) - Pattern library for the PeachCloud UI design system
 - [peach-web](https://git.coopcloud.tech/PeachCloud/peach-workspace/src/branch/main/peach-web) - A web interface for monitoring and interacting with the PeachCloud device

## Contributors

If you're interested in contributing to PeachCloud, please reach out to @glyph on Scuttlebutt or via email (glyph@mycelial.technology).

## Developer Diaries

 - [@ahdinosaur](https://github.com/ahdinosaur): `@6ilZq3kN0F+dXFHAPjAwMm87JEb/VdB+LC9eIMW3sa0=.ed25519`
  - 1: [`%bSkZCJBmNYUmECNKYOiWkgEeRxrlo2UghNBzE6Cph94=.sha256`](https://viewer.scuttlebot.io/%25bSkZCJBmNYUmECNKYOiWkgEeRxrlo2UghNBzE6Cph94%3D.sha256)
  - 2: [`%2L7gYAh2ih+7eFCrtObPWIUYHuGnJjwj4KCXrCIsWhM=.sha256`](https://viewer.scuttlebot.io/%252L7gYAh2ih%2B7eFCrtObPWIUYHuGnJjwj4KCXrCIsWhM%3D.sha256)
 - [@glyph](https://mycelial.technology): `@HEqy940T6uB+T+d9Jaa58aNfRzLx9eRWqkZljBmnkmk=.ed25519`
   - [`%mKUByRp4Gib6fqP1q2/dHg+ueSoR+Sj2Y0D7T0Np0D4=.sha256`](https://viewer.scuttlebot.io/%25mKUByRp4Gib6fqP1q2%2FdHg%2BueSoR%2BSj2Y0D7T0Np0D4%3D.sha256)
 - @notplants: `@5Pt3dKy2HTJ0mWuS78oIiklIX0gBz6BTfEnXsbvke9c=.ed25519` 
   - [`%Hhjn+QvmpEPDRC5DtRQlLbjpkNsX3dPEglGU7s4hLOI=.sha256`](https://viewer.scuttlebot.io/%25Hhjn%2BQvmpEPDRC5DtRQlLbjpkNsX3dPEglGU7s4hLOI%3D.sha256)

## Accounts

- [GitHub](https://github.com/peachcloud)
- [Twitter](https://twitter.com/peachcloudorg)
- [Email](mailto:peachcloudorg@gmail.com)
- [OpenCollective](https://opencollective.com/peachcloud)
